@@ -1,9 +1,9 @@
-from finorch.sessions.cit import CitSession
+from finorch.sessions.cit import CITSession
 from finorch.sessions.local import LocalSession
 from finorch.sessions.ozstar import OzStarSession
 
 session_map = {
     LocalSession.callsign: LocalSession,
     OzStarSession.callsign: OzStarSession,
-    CitSession.callsign: CitSession
+    CITSession.callsign: CITSession
 }
